"""
Class: ConfigurationReferencesBase
Description: Base class to hold configuration references for a vectorization profile.
"""
from pydantic import BaseModel

class ConfigurationReferencesBase(BaseModel):
    """
    Base class to hold configuration references for a vectorization profile.
    """
    pass
